summaryrefslogtreecommitdiffstats
path: root/test/stab.c
diff options
context:
space:
mode:
authorJames Laird <jlaird@hdfgroup.org>2006-08-02 15:59:05 (GMT)
committerJames Laird <jlaird@hdfgroup.org>2006-08-02 15:59:05 (GMT)
commitd296efb47ef9f8c643668aa3d5d45671e3cd9ac3 (patch)
treea61811f9aa295820fedbff565f36c001239dcdae /test/stab.c
parent676260a09b15ffcc7e36f7035613bef66db4bffa (diff)
downloadhdf5-d296efb47ef9f8c643668aa3d5d45671e3cd9ac3.zip
hdf5-d296efb47ef9f8c643668aa3d5d45671e3cd9ac3.tar.gz
hdf5-d296efb47ef9f8c643668aa3d5d45671e3cd9ac3.tar.bz2
[svn-r12524] Changed number of arguments to H5Gcreate_expand. Should stop the DT from
dying again.
Diffstat (limited to 'test/stab.c')
-rw-r--r--test/stab.c21
1 files changed, 13 insertions, 8 deletions
diff --git a/test/stab.c b/test/stab.c
index 164c8f8..2562423 100644
--- a/test/stab.c
+++ b/test/stab.c
@@ -329,7 +329,8 @@ lifecycle(hid_t fapl)
if(H5Pset_est_link_info(gcpl, LIFECYCLE_EST_NUM_ENTRIES, LIFECYCLE_EST_NAME_LEN) < 0) TEST_ERROR;
/* Create group for testing lifecycle */
- if((gid = H5Gcreate_expand(fid, LIFECYCLE_TOP_GROUP, gcpl, H5P_DEFAULT)) < 0) TEST_ERROR
+ if((gid = H5Gcreate_expand(fid, gcpl, H5P_DEFAULT)) < 0) TEST_ERROR
+ if((H5Llink(fid, LIFECYCLE_TOP_GROUP, gid, H5P_DEFAULT)) < 0) TEST_ERROR
/* Query group creation property settings */
if(H5Pget_local_heap_size_hint(gcpl, &lheap_size_hint) < 0) TEST_ERROR;
@@ -787,7 +788,8 @@ no_compact(hid_t fapl)
if(est_name_len != H5G_CRT_GINFO_EST_NAME_LEN) TEST_ERROR;
/* Create group for testing lifecycle */
- if((gid = H5Gcreate_expand(fid, NO_COMPACT_TOP_GROUP, gcpl, H5P_DEFAULT)) < 0) TEST_ERROR
+ if((gid = H5Gcreate_expand(fid, gcpl, H5P_DEFAULT)) < 0) TEST_ERROR
+ if((H5Llink(fid, NO_COMPACT_TOP_GROUP, gid, H5P_DEFAULT)) < 0) TEST_ERROR
/* Close GCPL */
if(H5Pclose(gcpl) < 0) TEST_ERROR;
@@ -873,6 +875,7 @@ gcpl_on_root(hid_t fapl)
hid_t gid2 = (-1); /* Datatype ID */
hid_t fcpl = (-1); /* File creation property list ID */
hid_t gcpl = (-1); /* Group creation property list ID */
+ hid_t lcpl = (-1); /* Link creation property list ID */
unsigned max_compact; /* Maximum # of links to store in group compactly */
unsigned min_dense; /* Minimum # of links to store in group "densely" */
char filename[NAME_BUF_SIZE];
@@ -911,15 +914,16 @@ gcpl_on_root(hid_t fapl)
/* Close GCPL */
if(H5Pclose(gcpl) < 0) TEST_ERROR;
- /* Create a group creation property list, with intermediate group creation set */
- if((gcpl = H5Pcreate(H5P_GROUP_CREATE)) < 0) TEST_ERROR;
- if(H5Pset_create_intermediate_group(gcpl, TRUE) < 0) TEST_ERROR
+ /* Create a link creation property list, with intermediate group creation set */
+ if((lcpl = H5Pcreate(H5P_LINK_CREATE)) < 0) TEST_ERROR;
+ if(H5Pset_create_intermediate_group(lcpl, TRUE) < 0) TEST_ERROR
/* Create a group and intermediate groups, to check if root group settings are inherited */
- if((gid2 = H5Gcreate_expand(gid, GCPL_ON_ROOT_BOTTOM_GROUP, gcpl, H5P_DEFAULT)) < 0) TEST_ERROR
+ if((gid2 = H5Gcreate_expand(gid, H5P_DEFAULT, H5P_DEFAULT)) < 0) TEST_ERROR
+ if((H5Llink(fid, GCPL_ON_ROOT_BOTTOM_GROUP, gid, lcpl)) < 0) TEST_ERROR
- /* Close GCPL */
- if(H5Pclose(gcpl) < 0) TEST_ERROR;
+ /* Close LCPL */
+ if(H5Pclose(lcpl) < 0) TEST_ERROR;
/* Query the group creation properties */
if((gcpl = H5Gget_create_plist(gid2)) < 0) TEST_ERROR;
@@ -960,6 +964,7 @@ gcpl_on_root(hid_t fapl)
error:
H5E_BEGIN_TRY {
+ H5Gclose(lcpl);
H5Gclose(gcpl);
H5Gclose(gid2);
H5Gclose(gid);